@@ -25,17 +25,22 @@ from opentelemetry.trace import Span
 from volcenginesdkarkruntime import Ark
 from volcenginesdkarkruntime.types.images.images import SequentialImageGenerationOptions
 
-from veadk.config import getenv
-from veadk.consts import DEFAULT_IMAGE_GENERATE_MODEL_NAME, DEFAULT_MODEL_AGENT_API_BASE
+from veadk.config import getenv, settings
+from veadk.consts import (
+    DEFAULT_IMAGE_GENERATE_MODEL_NAME,
+    DEFAULT_IMAGE_GENERATE_MODEL_API_BASE,
+)
 from veadk.utils.logger import get_logger
-from veadk.utils.misc import formatted_timestamp, read_png_to_bytes
+from veadk.utils.misc import formatted_timestamp, read_file_to_bytes
 from veadk.version import VERSION
 
 logger = get_logger(__name__)
 
 client = Ark(
-    api_key=getenv("MODEL_AGENT_API_KEY"),
-    base_url=getenv("MODEL_AGENT_API_BASE", DEFAULT_MODEL_AGENT_API_BASE),
+    api_key=getenv(
+        "MODEL_IMAGE_API_KEY", getenv("MODEL_AGENT_API_KEY", settings.model.api_key)
+    ),
+    base_url=getenv("MODEL_IMAGE_API_BASE", DEFAULT_IMAGE_GENERATE_MODEL_API_BASE),
 )
 
 
@@ -299,7 +304,7 @@ async def image_generate(
                         artifact=Part(
                             inline_data=Blob(
                                 display_name=filename,
-                                data=read_png_to_bytes(image_tos_url),
+                                data=read_file_to_bytes(image_tos_url),
                                 mime_type=mimetypes.guess_type(image_tos_url)[0],
                             )
                         ),
